@@ -1,9 +1,24 @@
 import os
-from notion_client.helpers import get_id
-from notion2md.console.formatter import *
 
+from notion_client.helpers import get_id
+
+from notion2md.console.formatter import *
+from notion2md.exceptions import UnInitializedConfigException
+
+def singleton(cls):
+    instance = {}
+    def get_instance(**kargs):
+        if cls not in instance:
+            if kargs:
+                instance[cls] = cls(**kargs)
+            else:
+                raise UnInitializedConfigException
+        return instance[cls]
+    return get_instance
+
+@singleton
 class Config(object):
-    __slots__ = ("file_name", "target_id", "output_path","download")
+    __slots__ = ("file_name", "target_id", "output_path","tmp_path","download","unzipped")
     def __init__(self,**kargs):
         if "url" in kargs and kargs['url']:
             self.target_id = get_id(kargs['url'])
@@ -26,13 +41,10 @@ class Config(object):
             self.download = True
         else:
             self.download = False
-        
-config = None
 
-def set_config(**kargs):
-    global config
-    config = Config(**kargs)
-
-def get_config():
-    global config
-    return config
\ No newline at end of file
+        if "unzipped" in kargs and kargs["unzipped"]:
+            self.unzipped = True
+            self.tmp_path = self.output_path
+        else:
+            self.unzipped = False
+            self.tmp_path = os.path.join(os.getcwd(),'tmp')
\ No newline at end of file
